@@ -466,6 +466,24 @@ class EErrorFacilityTestCase(unittest.TestCase):
         self.assertEqual(self.numerr, 0)
         self.assertFalse(hasattr(self, "gotit"))
 
+    def test_41_flush(self):
+        # Here the error handler is still set to None.
+        # First validate that nothing gets flushed (no error is buffered at this point).
+        self.flushed = LG_Error.flush()
+        self.assertEqual(self.flushed, False)
+        # Now generate a partial error message that is still buffered.
+        LG_Error.message("This is a partial error message.")
+        # Validate that it is still hidden.
+        self.numerr = LG_Error.printall(self.error_handler_test, self)
+        self.assertEqual(self.numerr, 0)
+        self.assertFalse(hasattr(self, "gotit"))
+        # Flush it.
+        self.flushed = LG_Error.flush()
+        self.assertEqual(self.flushed, True)
+        self.numerr = LG_Error.printall(self.error_handler_test, self)
+        self.assertEqual(self.numerr, 1)
+        self.assertRegexpMatches(self.errinfo.text, "partial")
+
     def test_50_set_orig_error_handler(self):
         # Set the error handler back to the default handler.
         # The error message is now visible (but we cannot test that).
@@ -692,7 +710,7 @@ class ZENLangTestCase(unittest.TestCase):
         # This sentence has no complete linkage. Validate that the library
         # doesn't mangle parsing with null-count>0 due to power_prune()'s
         # connector-discard optimization at null-count==0.  Without commit
-        # "Allow calling chart_parse() with and w/o nulls", the number of
+        # "Allow calling classic_parse() with and w/o nulls", the number of
         # linkages here is 1 instead of 2 and the unused_word_cost is 5.
         self.po = ParseOptions(min_null_count=0, max_null_count=999)
         linkages = Sentence('about people attended', self.d, self.po).parse()
