@@ -43,7 +43,7 @@
 
 #include "api-types.h"
 #include "corpus/corpus.h"
-#include "error.h"
+//#include "error.h"
 #include "utilities.h"
 
 typedef struct Cost_Model_s Cost_Model;
@@ -126,7 +126,7 @@ struct Sentence_s
 
 	/* Parse results */
 	int    num_linkages_found;  /* Total number before postprocessing.  This
-	                               is returned by the count() function */
+	                               is returned by the do_count() function */
 	size_t num_linkages_alloced;/* Total number of linkages allocated.
 	                               the number post-processed might be fewer
 	                               because some are non-canonical */
